Contrast — Thumbor 7.0.0a2 documentation

# Contrast

Usage: contrast(amount)

## Description

This filter increases or decreases the image contrast.

## Arguments

- `amount` - \(-100\) to \(100\) - The amount (in %) to change the image contrast. Positive numbers increase contrast and negative numbers decrease contrast.

## Example

http://localhost:8888/unsafe/filters:contrast(40)/https%3A%2F%2Fgithub.com%2Fthumbor%2Fthumbor%2Fraw%2Fmaster%2Fexample.jpg

http://localhost:8888/unsafe/filters:contrast(-40)/https%3A%2F%2Fgithub.com%2Fthumbor%2Fthumbor%2Fraw%2Fmaster%2Fexample.jpg